@@ -17,10 +17,12 @@ master_doc = 'index'
 extensions = []
 source_suffix = '.rst'
 exclude_patterns = ['_build', 'Thumbs.db', '.DS_Store']
-pygments_style = None
 extensions = [
     'sphinx.ext.autodoc',
 ]
+linkcheck_ignore = [
+    'https://sphinx-doc.org',
+]
 
 # HTML --------------------------------------------------------------------
 html_theme = 'sphinx_audeering_theme'
